==> ormnomnom-0.0.3.tgz: package/test/models.js <==
(function() {
  var BaseModel, exceptions, exports, models, unit, _ref;
  unit = require('platoon').unit;
  _ref = require('../'), models = _ref.models, exceptions = _ref.exceptions;
  BaseModel = models.BaseModel;
  module.exports = exports = {
    'test BaseModel static methods': unit({}, function(assert) {
      'Test BaseModel.lock disables models schema and meta methods, delegates to .compile and .create_manager';      var expected, fake_model_base;
      expected = new Object;
      expected.schema = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      expected.meta = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      fake_model_base = {
        compile: function(model_fn) {
          return assert.strictEqual(model_fn, expected);
        },
        create_manager: function(model_fn) {
          return assert.strictEqual(model_fn, expected);
        },
        lock: BaseModel.lock
      };
      fake_model_base.lock(expected);
      assert.throws(Error, function() {
        return expected.schema();
      });
      return assert.throws(Error, function() {
        return expected.meta();
      });
    }, function(assert) {
      'Test BaseModel.set_meta delegates to `model_fn._meta.set`';      var expected, i, mock_meta, mock_model, _ref2;
      mock_meta = {
        collection: {}
      };
      mock_meta.set = function(key, val) {
        return this.collection[key] = val;
      };
      mock_model = {
        _meta: mock_meta
      };
      expected = {};
      for (i = 0, _ref2 = ~~(Math.random() * 100) + 1; 0 <= _ref2 ? i < _ref2 : i > _ref2; 0 <= _ref2 ? i++ : i--) {
        expected["random_" + i] = Math.random();
      }
      BaseModel.set_meta(mock_model, expected);
      return assert.deepEqual(mock_meta.collection, expected);
    }, function(assert) {
      'Test BaseModel.set_schema delegates to `model_fn._schema.set`';      var expected, i, mock_model, mock_schema, _ref2;
      mock_schema = {
        collection: {}
      };
      mock_schema.set = function(key, val) {
        return this.collection[key] = val;
      };
      mock_model = {
        _schema: mock_schema
      };
      expected = {};
      for (i = 0, _ref2 = ~~(Math.random() * 100) + 1; 0 <= _ref2 ? i < _ref2 : i > _ref2; 0 <= _ref2 ? i++ : i--) {
        expected["random_" + i] = Math.random();
      }
      BaseModel.set_schema(mock_model, expected);
      return assert.deepEqual(mock_schema.collection, expected);
    }, function(assert) {
      'Test BaseModel.compile adds a primary key named `id` and aliases it if model_fn does not\nalready have a primary key.';      var AutoField, Meta, Schema, model, schema, _ref2;
      _ref2 = require('../lib/schema'), Schema = _ref2.Schema, Meta = _ref2.Meta;
      AutoField = require('../lib/fields').AutoField;
      model = function() {
        return typeof lol !== "undefined" && lol !== null;
      };
      schema = new Schema(model);
      schema.connect_related = assert.async(function() {
        return assert.ok('just testing that this gets triggered');
      });
      model._schema = schema;
      assert.fail(model._schema.get_field_by_name('id'));
      assert.fail(model._schema.get_field_by_name('pk'));
      BaseModel.compile(model);
      assert.ok(model._schema.get_field_by_name('id'));
      assert.ok(model._schema.get_field_by_name('pk'));
      assert.strictEqual(model._schema.get_field_by_name('id'), model._schema.get_field_by_name('pk'));
      return assert.isInstance(model._schema.get_field_by_name('id'), AutoField);
    }, function(assert) {
      'Test BaseModel.compile will not add a primary key if schema says that it already has one.';      var AutoField, Meta, Schema, model, schema, _ref2;
      _ref2 = require('../lib/schema'), Schema = _ref2.Schema, Meta = _ref2.Meta;
      AutoField = require('../lib/fields').AutoField;
      model = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      schema = new Schema(model);
      schema.connect_related = assert.async(function() {
        return assert.ok('just testing that this gets triggered');
      });
      schema.has_primary_key = true;
      model._schema = schema;
      assert.fail(model._schema.get_field_by_name('id'));
      assert.fail(model._schema.get_field_by_name('pk'));
      BaseModel.compile(model);
      assert.fail(model._schema.get_field_by_name('id'));
      return assert.fail(model._schema.get_field_by_name('pk'));
    }, function(assert) {
      'Test BaseModel.create_manager automatically creates an instance of Manager passing `model_fn`';      var Manager, model_fn;
      Manager = require('../lib/managers').Manager;
      model_fn = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      BaseModel.create_manager(model_fn);
      assert.isInstance(model_fn._default_manager, Manager);
      assert.isInstance(model_fn.objects, Manager);
      return assert.strictEqual(model_fn.objects, model_fn._default_manager);
    }, function(assert) {
      'Test BaseModel.create_manager will use user-provided managers';      var FakeManager, Manager, model_fn;
      Manager = require('../lib/managers').Manager;
      FakeManager = function(model_fn) {
        return assert.isInstance(this, FakeManager);
      };
      model_fn = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      model_fn.objects = FakeManager;
      BaseModel.create_manager(model_fn);
      assert.isInstance(model_fn._default_manager, Manager);
      assert.isInstance(model_fn.objects, FakeManager);
      return assert.strictNotEqual(model_fn.objects, model_fn._default_manager);
    }),
    'test BaseModel prototype methods': unit({}, function(assert) {
      'Test BaseModel#assign throws errors when given values not present in schema';      var Meta, MockModel, Schema, model, _ref2;
      _ref2 = require('../lib/schema'), Meta = _ref2.Meta, Schema = _ref2.Schema;
      MockModel = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      MockModel._schema = new Schema(MockModel);
      MockModel._meta = new Meta(MockModel);
      MockModel.prototype = BaseModel.prototype;
      MockModel.prototype.constructor = MockModel;
      model = new MockModel;
      return assert.throws(exceptions.ValidationError, function() {
        return model.assign({
          'anything': Math.random()
        });
      });
    }, function(assert) {
      'Test BaseModel#assign delegates to Field#apply_value.';      var MockModel, Schema, expected_field_name, model;
      Schema = require('../lib/schema').Schema;
      expected_field_name = "random_" + (~~(100 * Math.random()));
      MockModel = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      MockModel._schema = new Schema;
      MockModel._schema.set(expected_field_name, models.IntegerField());
      MockModel.prototype = BaseModel.prototype;
      MockModel.prototype.constructor = MockModel;
      model = new MockModel;
      return assert.doesNotThrow(exceptions.ValidationError, function() {
        var expected_value, value;
        value = {};
        expected_value = ~~(Math.random() * 100);
        value[expected_field_name] = expected_value;
        model.assign(value);
        return assert.equal(model[expected_field_name], expected_value);
      });
    }, function(assert) {
      'Test that BaseModel#save runs an update when `pk` is available';      var Model;
      Model = require('./fixtures/models').Model;
      return Model.objects.create({
        anything: 'anything',
        validated: 'okay'
      })(assert.async(function(err, instance) {
        var expected_name, pk;
        assert.fail(err);
        assert.ok(instance.pk);
        pk = instance.pk;
        expected_name = "anything_" + (~~(Math.random() * 100));
        instance.anything = expected_name;
        return instance.save()(assert.async(function(err, data) {
          assert.fail(err);
          return Model.objects.get({
            pk: pk
          })(assert.async(function(err, instance2) {
            assert.fail(err);
            assert.equal(instance2.pk, instance.pk);
            return assert.equal(instance2.anything, expected_name);
          }));
        }));
      }));
    }, function(assert) {
      'Test that BaseModel#save runs a create when `pk` is not available';      var Model, expected, model;
      Model = require('./fixtures/models').Model;
      expected = "I fully expect this to be " + (~~(Math.random() * 100));
      model = new Model({
        anything: expected,
        validated: 'okay'
      });
      assert.fail(model.pk);
      return model.save()(assert.async(function(err, data) {
        assert.fail(err);
        assert.ok(data.pk);
        return assert.equal(data.anything, expected);
      }));
    }, function(assert) {
      'Test that BaseModel#delete runs a delete when `pk` is available';      var Model;
      Model = require('./fixtures/models').Model;
      return Model.objects.create({
        anything: 'anything',
        validated: 'okay'
      })(assert.async(function(err, instance) {
        assert.fail(err);
        assert.ok(instance.pk);
        return instance["delete"]()(assert.async(function(err, data) {
          assert.fail(err);
          return Model.objects.filter({
            pk: instance.pk
          })(assert.async(function(err, data) {
            assert.fail(err);
            return assert.equal(data.length, 0);
          }));
        }));
      }));
    }, function(assert) {
      'Test that BaseModel#delete throws an error when `pk` is not available';      var Model, model;
      Model = require('./fixtures/models').Model;
      model = new Model({
        anything: 'anything',
        validated: 'okay'
      });
      assert.fail(model.pk);
      return assert.throws(Error, function() {
        return model["delete"]();
      });
    }, function(assert) {
      'Test that creating models with DateFields works as expected';      var Model, Related, creation, date, _ref2;
      _ref2 = [require('./fixtures/related'), require('./fixtures/models')], Related = _ref2[0].Related, Model = _ref2[1].Model;
      date = new Date;
      creation = Related.objects.create({
        model: Model.objects.create({
          anything: 'anything',
          validated: 'great'
        }),
        pub_date: date
      });
      return creation(assert.async(function(err, data) {
        assert.fail(err);
        assert.isInstance(data.pub_date, Date);
        assert.equal(data.pub_date.getUTCFullYear(), date.getUTCFullYear());
        assert.equal(data.pub_date.getUTCMonth(), date.getUTCMonth());
        return assert.equal(data.pub_date.getUTCDate(), date.getUTCDate());
      }));
    })
  };
}).call(this);

==> ormnomnom-0.0.5.tgz: package/test/models.js <==
(function() {
  var BaseModel, exceptions, exports, models, unit, _ref;
  unit = require('platoon').unit;
  _ref = require('../'), models = _ref.models, exceptions = _ref.exceptions;
  BaseModel = models.BaseModel;
  module.exports = exports = {
    'test BaseModel static methods': unit({}, function(assert) {
      'Test BaseModel.lock disables models schema and meta methods, delegates to .compile and .create_manager';
      var expected, fake_model_base;
      expected = new Object;
      expected.schema = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      expected.meta = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      fake_model_base = {
        compile: function(model_fn) {
          return assert.strictEqual(model_fn, expected);
        },
        create_manager: function(model_fn) {
          return assert.strictEqual(model_fn, expected);
        },
        lock: BaseModel.lock
      };
      fake_model_base.lock(expected);
      assert.throws(Error, function() {
        return expected.schema();
      });
      return assert.throws(Error, function() {
        return expected.meta();
      });
    }, function(assert) {
      'Test BaseModel.set_meta delegates to `model_fn._meta.set`';
      var expected, i, mock_meta, mock_model, _ref2;
      mock_meta = {
        collection: {}
      };
      mock_meta.set = function(key, val) {
        return this.collection[key] = val;
      };
      mock_model = {
        _meta: mock_meta
      };
      expected = {};
      for (i = 0, _ref2 = ~~(Math.random() * 100) + 1; 0 <= _ref2 ? i < _ref2 : i > _ref2; 0 <= _ref2 ? i++ : i--) {
        expected["random_" + i] = Math.random();
      }
      BaseModel.set_meta(mock_model, expected);
      return assert.deepEqual(mock_meta.collection, expected);
    }, function(assert) {
      'Test BaseModel.set_schema delegates to `model_fn._schema.set`';
      var expected, i, mock_model, mock_schema, _ref2;
      mock_schema = {
        collection: {}
      };
      mock_schema.set = function(key, val) {
        return this.collection[key] = val;
      };
      mock_model = {
        _schema: mock_schema
      };
      expected = {};
      for (i = 0, _ref2 = ~~(Math.random() * 100) + 1; 0 <= _ref2 ? i < _ref2 : i > _ref2; 0 <= _ref2 ? i++ : i--) {
        expected["random_" + i] = Math.random();
      }
      BaseModel.set_schema(mock_model, expected);
      return assert.deepEqual(mock_schema.collection, expected);
    }, function(assert) {
      'Test BaseModel.compile adds a primary key named `id` and aliases it if model_fn does not\nalready have a primary key.';
      var AutoField, Meta, Schema, model, schema, _ref2;
      _ref2 = require('../lib/schema'), Schema = _ref2.Schema, Meta = _ref2.Meta;
      AutoField = require('../lib/fields').AutoField;
      model = function() {
        return typeof lol !== "undefined" && lol !== null;
      };
      schema = new Schema(model);
      schema.connect_related = assert.async(function() {
        return assert.ok('just testing that this gets triggered');
      });
      model._schema = schema;
      assert.fail(model._schema.get_field_by_name('id'));
      assert.fail(model._schema.get_field_by_name('pk'));
      BaseModel.compile(model);
      assert.ok(model._schema.get_field_by_name('id'));
      assert.ok(model._schema.get_field_by_name('pk'));
      assert.strictEqual(model._schema.get_field_by_name('id'), model._schema.get_field_by_name('pk'));
      return assert.isInstance(model._schema.get_field_by_name('id'), AutoField);
    }, function(assert) {
      'Test BaseModel.compile will not add a primary key if schema says that it already has one.';
      var AutoField, Meta, Schema, model, schema, _ref2;
      _ref2 = require('../lib/schema'), Schema = _ref2.Schema, Meta = _ref2.Meta;
      AutoField = require('../lib/fields').AutoField;
      model = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      schema = new Schema(model);
      schema.connect_related = assert.async(function() {
        return assert.ok('just testing that this gets triggered');
      });
      schema.has_primary_key = true;
      model._schema = schema;
      assert.fail(model._schema.get_field_by_name('id'));
      assert.fail(model._schema.get_field_by_name('pk'));
      BaseModel.compile(model);
      assert.fail(model._schema.get_field_by_name('id'));
      return assert.fail(model._schema.get_field_by_name('pk'));
    }, function(assert) {
      'Test BaseModel.create_manager automatically creates an instance of Manager passing `model_fn`';
      var Manager, model_fn;
      Manager = require('../lib/managers').Manager;
      model_fn = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      BaseModel.create_manager(model_fn);
      assert.isInstance(model_fn._default_manager, Manager);
      assert.isInstance(model_fn.objects, Manager);
      return assert.strictEqual(model_fn.objects, model_fn._default_manager);
    }, function(assert) {
      'Test BaseModel.create_manager will use user-provided managers';
      var FakeManager, Manager, model_fn;
      Manager = require('../lib/managers').Manager;
      FakeManager = function(model_fn) {
        return assert.isInstance(this, FakeManager);
      };
      model_fn = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      model_fn.objects = FakeManager;
      BaseModel.create_manager(model_fn);
      assert.isInstance(model_fn._default_manager, Manager);
      assert.isInstance(model_fn.objects, FakeManager);
      return assert.strictNotEqual(model_fn.objects, model_fn._default_manager);
    }),
    'test BaseModel prototype methods': unit({}, function(assert) {
      'Test BaseModel#assign throws errors when given values not present in schema';
      var Meta, MockModel, Schema, model, _ref2;
      _ref2 = require('../lib/schema'), Meta = _ref2.Meta, Schema = _ref2.Schema;
      MockModel = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      MockModel._schema = new Schema(MockModel);
      MockModel._meta = new Meta(MockModel);
      MockModel.prototype = BaseModel.prototype;
      MockModel.prototype.constructor = MockModel;
      model = new MockModel;
      return assert.throws(exceptions.ValidationError, function() {
        return model.assign({
          'anything': Math.random()
        });
      });
    }, function(assert) {
      'Test BaseModel#assign delegates to Field#apply_value.';
      var MockModel, Schema, expected_field_name, model;
      Schema = require('../lib/schema').Schema;
      expected_field_name = "random_" + (~~(100 * Math.random()));
      MockModel = function() {
        return typeof noop !== "undefined" && noop !== null;
      };
      MockModel._schema = new Schema;
      MockModel._schema.set(expected_field_name, models.IntegerField());
      MockModel.prototype = BaseModel.prototype;
      MockModel.prototype.constructor = MockModel;
      model = new MockModel;
      return assert.doesNotThrow(exceptions.ValidationError, function() {
        var expected_value, value;
        value = {};
        expected_value = ~~(Math.random() * 100);
        value[expected_field_name] = expected_value;
        model.assign(value);
        return assert.equal(model[expected_field_name], expected_value);
      });
    }, function(assert) {
      'Test that BaseModel#save runs an update when `pk` is available';
      var Model;
      Model = require('./fixtures/models').Model;
      return Model.objects.create({
        anything: 'anything',
        validated: 'okay'
      })(assert.async(function(err, instance) {
        var expected_name, pk;
        assert.fail(err);
        assert.ok(instance.pk);
        pk = instance.pk;
        expected_name = "anything_" + (~~(Math.random() * 100));
        instance.anything = expected_name;
        return instance.save()(assert.async(function(err, data) {
          assert.fail(err);
          return Model.objects.get({
            pk: pk
          })(assert.async(function(err, instance2) {
            assert.fail(err);
            assert.equal(instance2.pk, instance.pk);
            return assert.equal(instance2.anything, expected_name);
          }));
        }));
      }));
    }, function(assert) {
      'Test that BaseModel#save runs a create when `pk` is not available';
      var Model, expected, model;
      Model = require('./fixtures/models').Model;
      expected = "I fully expect this to be " + (~~(Math.random() * 100));
      model = new Model({
        anything: expected,
        validated: 'okay'
      });
      assert.fail(model.pk);
      return model.save()(assert.async(function(err, data) {
        assert.fail(err);
        assert.ok(data.pk);
        return assert.equal(data.anything, expected);
      }));
    }, function(assert) {
      'Test that BaseModel#delete runs a delete when `pk` is available';
      var Model;
      Model = require('./fixtures/models').Model;
      return Model.objects.create({
        anything: 'anything',
        validated: 'okay'
      })(assert.async(function(err, instance) {
        assert.fail(err);
        assert.ok(instance.pk);
        return instance["delete"]()(assert.async(function(err, data) {
          assert.fail(err);
          return Model.objects.filter({
            pk: instance.pk
          })(assert.async(function(err, data) {
            assert.fail(err);
            return assert.equal(data.length, 0);
          }));
        }));
      }));
    }, function(assert) {
      'Test that BaseModel#delete throws an error when `pk` is not available';
      var Model, model;
      Model = require('./fixtures/models').Model;
      model = new Model({
        anything: 'anything',
        validated: 'okay'
      });
      assert.fail(model.pk);
      return assert.throws(Error, function() {
        return model["delete"]();
      });
    }, function(assert) {
      'Test that creating models with DateFields works as expected';
      var Model, Related, creation, date, _ref2;
      _ref2 = [require('./fixtures/related'), require('./fixtures/models')], Related = _ref2[0].Related, Model = _ref2[1].Model;
      date = new Date;
      creation = Related.objects.create({
        model: Model.objects.create({
          anything: 'anything',
          validated: 'great'
        }),
        pub_date: date
      });
      return creation(assert.async(function(err, data) {
        assert.fail(err);
        assert.isInstance(data.pub_date, Date);
        assert.equal(data.pub_date.getUTCFullYear(), date.getUTCFullYear());
        assert.equal(data.pub_date.getUTCMonth(), date.getUTCMonth());
        return assert.equal(data.pub_date.getUTCDate(), date.getUTCDate());
      }));
    })
  };
}).call(this);
